"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const serverPluginHmr_1 = require("../server/serverPluginHmr");
const resolveVue_1 = require("../utils/resolveVue");
const serverPluginModuleResolve_1 = require("../server/serverPluginModuleResolve");
const debug = require('debug')('vite:build:resolve');
exports.createBuildResolvePlugin = (root, cdn, srcRoots, resolver) => {
    return {
        name: 'vite:resolve',
        async resolveId(id) {
            if (id === serverPluginHmr_1.hmrClientId) {
                return serverPluginHmr_1.hmrClientId;
            }
            else if (id.startsWith('/')) {
                // if id starts with any of the src root directories, it's a file request
                if (srcRoots.some((root) => id.startsWith(root))) {
                    return;
                }
                const resolved = resolver.requestToFile(id);
                debug(id, `-->`, resolved);
                return resolved;
            }
            else if (id === 'vue') {
                if (!cdn) {
                    return resolveVue_1.resolveVue(root).runtime;
                }
                else {
                    return {
                        id: resolveVue_1.resolveVue(root).cdnLink,
                        external: true
                    };
                }
            }
            else if (!id.startsWith('.')) {
                const request = resolver.idToRequest(id);
                if (request) {
                    const resolved = resolver.requestToFile(request);
                    debug(id, `-->`, request, `--> `, resolved);
                    return resolved;
                }
                else {
                    const webModulePath = await serverPluginModuleResolve_1.resolveWebModule(root, id);
                    if (webModulePath) {
                        return webModulePath;
                    }
                }
            }
        },
        load(id) {
            if (id === serverPluginHmr_1.hmrClientId) {
                return `export const hot = {accept(){},on(){}}`;
            }
        }
    };
};
