"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = __importDefault(require("path"));
const slash_1 = __importDefault(require("slash"));
exports.queryRE = /\?.*$/;
exports.hashRE = /\#.*$/;
exports.cleanUrl = (url) => url.replace(exports.hashRE, '').replace(exports.queryRE, '');
exports.resolveRelativeRequest = (importer, id) => {
    const resolved = slash_1.default(path_1.default.posix.resolve(path_1.default.dirname(importer), id));
    const queryMatch = id.match(exports.queryRE);
    return {
        url: resolved,
        pathname: exports.cleanUrl(resolved),
        query: queryMatch ? queryMatch[0] : ''
    };
};
const httpRE = /^https?:\/\//;
exports.isExternalUrl = (url) => httpRE.test(url);
const imageRE = /\.(png|jpe?g|gif|svg|ico)(\?.*)?$/;
const mediaRE = /\.(mp4|webm|ogg|mp3|wav|flac|aac)(\?.*)?$/;
const fontsRE = /\.(woff2?|eot|ttf|otf)(\?.*)?$/i;
/**
 * Check if a file is a static asset that vite can process.
 */
exports.isStaticAsset = (file) => {
    return imageRE.test(file) || mediaRE.test(file) || fontsRE.test(file);
};
/**
 * Check if a request is an import from js (instead of fetch() or ajax requests)
 * A request qualifies as long as it's not from page (no ext or .html).
 * this is because non-js files can be transformed into js and import json
 * as well.
 */
exports.isImportRequest = (ctx) => {
    const referer = exports.cleanUrl(ctx.get('referer'));
    return /\.\w+$/.test(referer) && !referer.endsWith('.html');
};
